//
//  PFPhotoViewController.m
//  PhotoFlickr
//
//  Created by Thao Nguyen Huy on 7/1/13.
//  Copyright (c) 2013 CNC Software. All rights reserved.
//

#import "PFPhotoViewController.h"
#import "PFPhoto.h"
#import "PFUser.h"
#import "UIImageView+AFNetworking.h"
#import "SVProgressHUD.h"
#import "PFCommentCell.h"

@implementation PFPhotoViewController {
@private
    NSArray *_comments;
}

@synthesize scrollView      = _scrollView;
@synthesize photoImageView  = _photoImageView;
@synthesize tableView       = _tableView;
@synthesize ownerNameLabel  = _ownerNameLabel;
@synthesize deviderView     = _deviderView;
@synthesize photoBackgroundView     = _photoBackgroundView;
@synthesize ownerLocationLabel      = _ownerLocationLabel;
@synthesize ownerAvatarImageView    = _ownerAvatarImageView;
@synthesize userBackgroundView      = _userBackgroundView;
@synthesize photo = _photo;

- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil {
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    if (self) {
        // Custom initialization
    }
    return self;
}

- (id)initWithTitle:(NSString *)title {
    self = [super initWithNibName:NSStringFromClass([self class]) bundle:nil];
    if (self) {
        self.title = title;
    }
    return self;
}

- (void)viewDidLoad {
    [super viewDidLoad];
    [self showContents];
    [UIApplication sharedApplication].networkActivityIndicatorVisible = YES;
    [_photo getCommentsWithCompletionBlock:^(NSArray *comments, NSError *error) {
        if (!error) {
            _comments = comments;
            [_tableView reloadData];
        }
        [UIApplication sharedApplication].networkActivityIndicatorVisible = NO;
    }];
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

#pragma mark - Custom methods
- (void)showContents {
    float screenHeight = [[UIScreen mainScreen] bounds].size.height;
    _scrollView.contentSize = CGSizeMake(320, screenHeight + 328 - (screenHeight - 270));
    [_ownerAvatarImageView setImageWithURL:_photo.owner.avatarImageURL placeholderImage:nil];
    [_photoImageView setImageWithURL:_photo.imageSize150URL placeholderImage:nil];
    if (_photo.owner.realName.length > 0) {
        _ownerNameLabel.text = _photo.owner.realName;
    }
    else if (_photo.owner.userName.length > 0) {
        _ownerNameLabel.text = _photo.owner.userName;
    }
    else {
        _ownerNameLabel.text = @"Unknow";
    }
    _ownerLocationLabel.text = _photo.owner.location;
}

#pragma mark - UITableViewDataSource
- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    return _comments.count;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    static NSString *CellIdentifier = @"PFCommentCell";
    PFCommentCell *cell = [tableView dequeueReusableCellWithIdentifier:CellIdentifier];
    if (cell == nil) {
        cell = [PFCommentCell cellFromNib];
    }
    PFComment *currentComment = _comments[indexPath.row];
    cell.comment = currentComment;
    return cell;
}

#pragma mark - UITableViewDelegate
- (CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath {
    return [PFCommentCell heightForCellWithPost:_comments[indexPath.row]];
}

@end
