//
//  PFSearchViewController.m
//  PhotoFlickr
//
//  Created by Thao Nguyen Huy on 7/1/13.
//  Copyright (c) 2013 CNC Software. All rights reserved.
//

#import "PFSearchViewController.h"
#import "SVProgressHUD.h"
#import "PFPhoto.h"
#import "PFPhotoCell.h"
#import "PFPhotoViewController.h"

@implementation PFSearchViewController {
@private
    NSArray *_photos;
}

@synthesize tableView = _tableView;
@synthesize searchBar = _searchBar;

- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil {
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    if (self) {
        // Custom initialization
        self.title = NSLocalizedString(@"Photo Flickr", @"The title of photo searching screen");
        UIBarButtonItem *backButton = [[UIBarButtonItem alloc] initWithTitle:@"Back" style:UIBarButtonItemStyleBordered target:nil action:nil];
        self.navigationItem.backBarButtonItem = backButton;
    }
    return self;
}

- (void)viewDidLoad {
    [super viewDidLoad];

}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

#pragma mark - UISearchBarDelegate
- (void)searchBarTextDidBeginEditing:(UISearchBar *)searchBar {
    
}

- (void)searchBarCancelButtonClicked:(UISearchBar *)searchBar {
    [searchBar resignFirstResponder];
}

- (void)searchBarSearchButtonClicked:(UISearchBar *)searchBar {
    [searchBar resignFirstResponder];
    _photos = nil;
    [_tableView reloadData];
    [SVProgressHUD showWithStatus:@"Looking up..." maskType:SVProgressHUDMaskTypeGradient];
    [PFPhoto searchPhotosByKeyword:searchBar.text completionBlock:^(NSArray *photos, NSError *error) {
        if (!error) {
            [SVProgressHUD showSuccessWithStatus:@"Finished"];
            _photos = photos;
            [_tableView reloadData];
        }
        else {
            LogError(@"%@", error);            
            [SVProgressHUD showErrorWithStatus:@"Not found"];
        }
    }];
}

#pragma mark - UITableViewDataSource
- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    return _photos.count;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    static NSString *CellIdentifier = @"PFPhotoCell";
    PFPhotoCell *cell = [tableView dequeueReusableCellWithIdentifier:CellIdentifier];
    if (cell == nil) {
        cell = [PFPhotoCell cellFromNib];
    }
    PFPhoto *selectedPhoto = _photos[indexPath.row];
    cell.photo = selectedPhoto;
    return cell;
}

#pragma mark - UITableViewDelegate
- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath {
    PFPhoto *selectedPhoto = _photos[indexPath.row];
    PFPhotoViewController *photoViewController = [[PFPhotoViewController alloc] initWithTitle:selectedPhoto.title];
    photoViewController.photo = selectedPhoto;
    [self.navigationController pushViewController:photoViewController animated:YES];
}

@end
