//
//  PFPhoto.m
//  PhotoFlickr
//
//  Created by Thao Nguyen Huy on 7/1/13.
//  Copyright (c) 2013 CNC Software. All rights reserved.
//

#import "PFPhoto.h"
#import "PFAPIClient.h"
#import "NSDictionary+PFCategory.h"
#import "PFUser.h"
#import "PFComment.h"

static NSString *const NumberOfPhotosPerPage   = @"50";
static NSString *const NoJsonCallback          = @"1";

@implementation PFPhoto

#pragma mark - Class methods
+ (void)searchPhotosByKeyword:(NSString *)keyword completionBlock:(void (^)(NSArray *, NSError *))block {
    NSDictionary *params = @{
        kFieldNameAPIKey : kFlickrApplicationKey,
        kFieldNameMethod : kFlickrMethodPhotosSearch,
        kFieldNameFormat : kFieldNameJson,
        kFieldNameText   : keyword,
        kFieldNamePerPage : NumberOfPhotosPerPage,
        kFieldNameNoJsonCallback : NoJsonCallback
    };
    
    [[PFAPIClient sharedClient] postPath:kURLBaseForAPI
                              parameters:params
                                 success:^(AFHTTPRequestOperation *operation, id responseObject)
     {         
         NSString *status = [responseObject valueForKeyPath:kFieldNameStat];
         if ([status isEqualToString:@"ok"]) {
             NSDictionary *responseData = [responseObject valueForKeyPath:kFieldNamePhotos];
             NSArray *photosFromResponse = [responseData valueForKeyPath:kFieldNamePhoto];
             NSMutableArray *mutablePhotos = [NSMutableArray arrayWithCapacity:photosFromResponse.count];
             for (NSDictionary *attributes in photosFromResponse) {
                 PFPhoto *photo = [[PFPhoto alloc] initWithAttributes:attributes];
                 [photo getInfoWithCompletionBlock:nil];
                 [mutablePhotos addObject:photo];
             }
             if (block) {
                 block([NSArray arrayWithArray:mutablePhotos], nil);
             }
         }
         else {
             if (block) {
                 NSError *error = [[NSError alloc] init];
                 block([NSArray array], error);
             }
         }
     } failure:^(AFHTTPRequestOperation *operation, NSError *error) {
         if (block) {
             block([NSArray array], error);
         }
     }];
}

@synthesize photoId = _photoId;
@synthesize title   = _title;
@synthesize secret  = _secret;
@synthesize farm    = _farm;
@synthesize owner   = _owner;
@synthesize serverId = _serverId;

- (NSString *)description {
    return [NSString stringWithFormat:@"     Photo: id=%@, title=%@, secret=%@, owner=%@",
            _photoId, _title, _secret, _owner];
}

- (id)initWithAttributes:(NSDictionary *)attributes {
    if (self = [super init]) {
        _photoId    = [attributes stringForKey:kFieldNameId];
        _title      = [attributes stringForKey:kFieldNameTitle];
        _secret     = [attributes stringForKey:kFieldNameSecret];
        _farm       = [attributes stringForKey:kFieldNameFarm];
        _serverId   = [attributes stringForKey:kFieldNameServer];
    }
    return self;
}

- (NSURL *)imageSize150URL {
    return [NSURL URLWithString:[NSString stringWithFormat:@"http://farm%@.staticflickr.com/%@/%@_%@_q.jpg",
                                 _farm, _serverId, _photoId, _secret]];
}

- (NSURL *)imageSize240URL {
    return [NSURL URLWithString:[NSString stringWithFormat:@"http://farm%@.staticflickr.com/%@/%@_%@_m.jpg",
                                 _farm, _serverId, _photoId, _secret]];
}

- (void)getInfoWithCompletionBlock:(void (^)(NSError *))block {
    NSDictionary *params = @{
        kFieldNameAPIKey : kFlickrApplicationKey,
        kFieldNameMethod : kFlickrMethodPhotoGetInfo,
        kFieldNameFormat : kFieldNameJson,
        kFieldNameSecret : _secret,
        kFieldNamePhotoId : _photoId,
        kFieldNameNoJsonCallback : NoJsonCallback
    };
    
    [[PFAPIClient sharedClient] postPath:kURLBaseForAPI
                              parameters:params
                                 success:^(AFHTTPRequestOperation *operation, id responseObject)
     {
         LogInfo(@"%@", responseObject);         
         NSString *status = [responseObject valueForKeyPath:kFieldNameStat];
         if ([status isEqualToString:@"ok"]) {
             NSDictionary *responseData = [responseObject valueForKeyPath:kFieldNamePhoto];
             NSDictionary *photoOwner = [responseData objectForKey:kFieldNameOwner];
             _owner = [[PFUser alloc] initWithAttributes:photoOwner];
             if (block) {
                 block(nil);
             }
         }
         else {
             if (block) {
                 NSError *error = [[NSError alloc] init];
                 block(error);
             }
         }
     } failure:^(AFHTTPRequestOperation *operation, NSError *error) {
         if (block) {
             block(error);
         }
     }];
}

- (void)getCommentsWithCompletionBlock:(void (^)(NSArray *, NSError *))block {
    NSDictionary *params = @{
         kFieldNameAPIKey : kFlickrApplicationKey,
         kFieldNameMethod : kFlickrMethodPhotosCommentsGetList,
         kFieldNameFormat : kFieldNameJson,
         kFieldNameNoJsonCallback : NoJsonCallback,
         kFieldNamePhotoId: _photoId
    };

    [[PFAPIClient sharedClient] postPath:kURLBaseForAPI
                              parameters:params
                                 success:^(AFHTTPRequestOperation *operation, id responseObject)
     {
         LogInfo(@"%@", responseObject);
         NSString *status = [responseObject valueForKeyPath:kFieldNameStat];
         if ([status isEqualToString:@"ok"]) {
             NSDictionary *responseData = [responseObject valueForKeyPath:kFieldNameComments];
             NSArray *commentsFromResponse = [responseData valueForKeyPath:kFieldNameComment];
             NSMutableArray *mutablePhotos = [NSMutableArray arrayWithCapacity:commentsFromResponse.count];
             for (NSDictionary *attributes in commentsFromResponse) {
                 PFComment *comment = [[PFComment alloc] initWithAttributes:attributes];
                 [mutablePhotos addObject:comment];
             }
             if (block) {
                 block([NSArray arrayWithArray:mutablePhotos], nil);
             }
         }
         else {
             if (block) {
                 NSError *error = [[NSError alloc] init];
                 block([NSArray array], error);
             }
         }
     } failure:^(AFHTTPRequestOperation *operation, NSError *error) {
         if (block) {
             block([NSArray array], error);
         }
     }];
}

@end
